@@ -1,5 +1,6 @@
 from typing import Union
 import sys, types, inspect
+from math import sqrt
 
 # ERRORS:
 class VectorError(Exception):
@@ -13,10 +14,14 @@ class Vector:
 	# FUNCTIONS
 	def __init__(self, *argv):
 		"""Check amount of args and set them"""
-		if len(argv) < 1 or len(argv) > 4 or [True for var in argv if not (type(var) == int or type(var) == float)]:
-			raise ValueError('Vector type only supports 1 to 4 integers and floats')
+		if type(argv[0]) == tuple and len(argv) == 1 and len(argv[0]) > 0 and len(argv[0]) < 5:
+			argv = tuple([var for var in argv[0]])
+
+		if len(argv) < 1 or len(argv) > 4 or [True for var in argv if not(type(var) == int or type(var) == float)]:
+			raise ValueError('Vector type only supports 1 to 4 integers and floats or tuple')
+
+		self.attrlist = ['x', 'y', 'z', 't']
 
-		self.attrlist = ['x', 'y', 'z', 't']		
 		for i in range(len(self.attrlist)):
 			try:
 				exec(f'self.{self.attrlist[i]} = {argv[i]}')
@@ -67,6 +72,43 @@ class Vector:
 		if len(self) > 3: result = f"Vector({self.x}, {self.y}, {self.z}, {self.t})"
 		return result
 
+	def mag(self):
+		summ = 0
+		for i in range(len(self)):
+		    summ = self[i]*self[i] + summ    
+		return pow(summ,0.5)
+	def magnitude(self):
+		return self.mag()
+		#
+
+	def normalized(self):
+		mag = self.mag()
+		if len(self) == 1:
+			return Vector(1)
+		if len(self) == 2:
+			return Vector(self.x/mag, self.y/mag)
+		if len(self) == 3:
+			return Vector(self.x/mag, self.y/mag, self.z/mag)
+		if len(self) == 4:
+			return Vector(self.x/mag, self.y/mag, self.z/mag, self.t/mag)
+		else:
+			raise VectorError(f'an error occured during the normalization of {self.type}')
+	def norm(self):
+		return self.normalized()
+		#		
+
+	def positive(self):
+		if len(self) == 1:
+			return Vector(sqrt(self.x**2))
+		if len(self) == 2:
+			return Vector(sqrt(self.x**2), sqrt(self.y**2))
+		if len(self) == 3:
+			return Vector(sqrt(self.x**2), sqrt(self.y**2), sqrt(self.z**2))
+		if len(self) == 4:
+			return Vector(sqrt(self.x**2), sqrt(self.y**2), sqrt(self.z**2), sqrt(self.t**2))
+		else:
+			raise VectorError(f'an error occured during the positive of {self.type}')
+			
 	# BINARY OPERATORS
 	def __add__(self, other):
 		if isinstance(other, Vector):
@@ -1091,5 +1133,21 @@ def unvector(self):
 	if len(self) > 2: result = (self.x, self.y, self.z)
 	if len(self) > 3: result = (self.x, self.y, self.z, self.t)
 	return result
+unv = unvector
 
-unv = unvector
\ No newline at end of file
+def magnitude(self):
+	if not isinstance(self, Vector):
+		raise VectorError(f"cannot find magnitude of type '{type(self).__name__}'")
+	return self.mag()
+mag = magnitude
+
+def normalized(self):
+	if not isinstance(self, Vector):
+		raise VectorError(f"cannot normalize type '{type(self).__name__}'")
+	return self.normalized()
+norm = normalized
+
+def positive(self):
+	if not isinstance(self, Vector):
+		raise VectorError(f"cannot make type '{type(self).__name__}' positive")
+	return self.positive()
\ No newline at end of file
